.. _workflow_interfaces:

=========================
DIPY Workflows Interfaces
=========================

.. toctree::

    basic_flow.rst
    data_fetch.rst
    denoise_flow.rst
    gibbs_unringing_flow.rst
    buan_flow.rst
    bundle_segmentation_flow.rst